@@ -1,9 +1,12 @@
 from .timeutil import limit_time, timeit
 from .memoryutil import limit_memory, memoryit
+from .utility import limit_resource, measureit
 
 __all__ = [
     "limit_time",
     "timeit",
     "limit_memory",
     "memoryit",
+    "limit_resource",
+    "measureit",
 ]
